% ENDOR orientation selection in a powder
%=====================================================================
clear; clc
[nu, s, par] = eprload('Zn_ZSM5_17_ENDOR_12111_50K.DSC');
s = real(s);


% ENDOR experiment settings
ExpW = struct('mwFreq', 95, ...
    'ExciteWidth', 100, ...
    'Range', [1 60], ...
    'Field', 3395.97, ...
    'nPoints', 500, ...
    'Temperature', 50);
ExpQ = struct('mwFreq', par.MWFQ/1e9, ...
    'ExciteWidth', 100, ...
    'Range', [1 50], ...
    'Field', par.B0VL*1e3, ...
    'nPoints', 250, ...
    'Temperature', 50);
ExpX = struct('mwFreq', 9.5, ...
    'ExciteWidth', 100, ...
    'Range', [1 50], ...
    'Field', 339.597, ...
    'nPoints', 250, ...
    'Temperature', 50);

Opt = struct('Enhancement', 'off',...
    'GridSize', 31);

% Spin system
Sys = struct('g', [1.9951, 1.9984, 2.0015],...
    'Nucs', '17O', 'A_', [52, 5, 0], ...
    'Q', [0, 0.1],...
    'HStrain', [1, 1, 1]*220, 'lwEndor', 4);

[nusimW, simW] = salt(Sys, ExpW, Opt);
[nusimQ, simQ] = salt(Sys, ExpQ, Opt);
[nusimX, simX] = salt(Sys, ExpX, Opt);
Opt.Transitions = [1, 2; 2, 3; 3, 4; 4, 5; 5, 6];
[~, simWb] = salt(Sys, ExpW, Opt);
[~, simQb] = salt(Sys, ExpQ, Opt);
[~, simXb] = salt(Sys, ExpX, Opt);
Opt.Transitions = [7, 8; 8, 9; 9, 10; 10, 11; 11, 12];
[~, simWa] = salt(Sys, ExpW, Opt);
[~, simQa] = salt(Sys, ExpQ, Opt);
[~, simXa] = salt(Sys, ExpX, Opt);

nusimQ = nusimQ;
simQ = simQ;
s_ = s;
s = rescaledata(s_, simQ', 'lsq0');
nusimW_ = nusimW - larmorfrq('17O', ExpW.Field);
nusimQ_ = nusimQ - larmorfrq('17O', ExpQ.Field);
nu_ = nu - larmorfrq('17O', ExpQ.Field);
nusimX_ = nusimX - larmorfrq('17O', ExpX.Field);

set(0, 'DefaultLineLineWidth', 1.5)


figure('Position', [0, 0, 1280, 720]);

subplot(311); hold on
plot(nusimW, simW, 'r', DisplayName='Sim')
plot(nusimW, simWa, 'g', DisplayName='\nu\alpha')
plot(nusimW, simWb, 'b', DisplayName='\nu\beta')
hold off
xlabel('Frequqncy [MHz]');
ylabel('Intensity [a.u.]')
title('W-band ENDOR spectra');
set(gca, 'YTick', [], 'FontSize', 12)
legend(FontSize=12)

subplot(312); hold on
plot(nu, s, 'k', DisplayName='Exp')
plot(nusimQ, simQ, 'r', DisplayName='Sim')
plot(nusimQ, simQa, 'g', DisplayName='\nu\alpha')
plot(nusimQ, simQb, 'b', DisplayName='\nu\beta')
hold off
xlabel('Frequqncy [MHz]');
ylabel('Intensity [a.u.]')
title('Q-band ENDOR spectra');
set(gca, 'YTick', [], 'FontSize', 12)
legend(FontSize=12)

subplot(313); hold on
plot(nusimX, simX, 'r', DisplayName='Sim')
plot(nusimX, simXa, 'g', DisplayName='\nu\alpha')
plot(nusimX, simXb, 'b', DisplayName='\nu\beta')
hold off
xlabel('Frequqncy [MHz]');
ylabel('Intensity [a.u.]')
title('X-band ENDOR spectra');
set(gca, 'YTick', [], 'FontSize', 12)
legend(FontSize=12)
print('SimZnZSM5_ENDOR', '-dpng', '-r300')