% input: contour_level, filename ,and/or Opt
% One can obtain contourlevels with get_contourL
% Opt can include:
% "Complex": Take (Abs, Real, or Imag) part of the spectrum
% "freq_res": freq. domain resolution
%   (integer > time domain points)
% "Symmetrization": Symmetrization
%   ("none", "diagonal", "anti-diagonal", "Both")
% "BaselineOrder": Polynomial Order for baseline correction
%   (1-6)
% "MakePlot": To make plot or to simply export parameters
%   (1 for yes (default))
% output: nu (freq. domain axis),sy (fft spectrum)
function [nu, sy, param, contour_level] = plot_HYSCORE(contour_level, fileName, Opt)
Opt_.Complex = '';
Opt_.freq_res = [];
Opt_.Symmetrization = '';
Opt_.BaselineOrder = [];
Opt_.MakePlot = '';
if nargin < 3
    Opt = Opt_;
    if nargin <= 1
        [File, Path] = uigetfile({...
            '*.DTA;*.dta;*.spc','Bruker (*.dta,*.spc)'},...
            'Load EPR data file...');
        disp(File)
        fileName_ = split(File, '.');
        fileName = [Path, fileName_{1}];
        if nargin == 0 || ~isnumeric(contour_level)
            contour_level = get_contourL(fileName);
        end
    end
end
[t0,s0,param] = eprload(fileName);
[sl, ~] = size(s0); % spectrum length
All_Opt = {'Complex',...
    'freq_res',...
    'Symmetrization',...
    'BaselineOrder',...
    'MakePlot'};
All_Opt_val = {'real', 4*sl, 'None', 3, 1};
for i = 1:numel(All_Opt)
    if ~isfield(Opt, All_Opt{i}) || isempty(Opt.(All_Opt{i}))
        Opt.(All_Opt{i}) = All_Opt_val{i};
    end
end

if numel(Opt.BaselineOrder) == 1
    blo1 = Opt.BaselineOrder;            % baseline polynomial order
    blo2 = Opt.BaselineOrder;
else
    blo1 = Opt.BaselineOrder(1);
    blo2 = Opt.BaselineOrder(2);
end
freq_res = Opt.freq_res;

t1 = t0{1};
win = apowin('ham+', sl);
Opt.Complex = lower(Opt.Complex);
switch Opt.Complex
    case 'real'
        s0 = real(s0);
    case 'imag'
        s0 = imag(s0);
    case 'abs'
        s0 = abs(s0);
end
s1 = basecorr(s0,[1 2],[blo1 blo2]);
s0 = s1.*(win*win.');
s1 = fftshift(fftn(s0,[freq_res, freq_res]));
s0 = abs(s1);
% M = length(s0);
% s0(M+1,:) = s0(1,:); s0(:,M+1) = s0(:,1);
% s1 = s0;
sy = s0;
sy = HYSCORE_Symmetrization(sy, Opt.Symmetrization);
dt = (t1(2)-t1(1))/1e3;
nu = fdaxis(dt, freq_res);
if Opt.MakePlot == 1
    figure(100)
    contour(nu,nu,sy,contour_level);
else
    close(figure(100))
end
end